window.Gleam.initSearch([{"doc":"glerd","title":"glerd","content":"# Glerd\n\n[![Package Version](https://img.shields.io/hexpm/v/glerd)](https://hex.pm/packages/glerd)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/glerd/)\n![Erlang-compatible](https://img.shields.io/badge/target-erlang-a2003e)\n![JavaScript-compatible](https://img.shields.io/badge/target-javascript-f1e05a)\n\nGlerd is tooling, written in [Gleam](https://gleam.run/), that generates\nmetadata that describes Gleam [Records](https://tour.gleam.run/data-types/records/).\nThis metadata can be used to generate Gleam code that works with those records,\nas a substitute for runtime reflection, which does not exist in Gleam.\n\n## Installing\n\n```sh\ngleam add --dev glerd\n```\n\n## Usage\n\nRun:\n\n```sh\ngleam run -m glerd\n```\n\nThis reads Gleam source files in the `src` directory of a project and creates\na `glerd_gen.gleam` output file containing metadata for each of the Records in\nthose files.\n\n## Example output\n\nIf this record exists in a source file:\n\n###### src/user.gleam\n\n```gleam\npub type User {\n  /// some metadata\n  User(id: Int, name: String, email: String)\n}\n```\n\nthe output will be:\n\n###### src/glerd_gen.gleam\n\n```gleam\nimport glerd/types\n\npub const record_info = [\n  #(\n    &quot;User&quot;, // record name\n    &quot;user&quot;, // module name\n    [\n      #(&quot;id&quot;, types.IsInt), #(&quot;name&quot;, types.IsString),\n      #(&quot;email&quot;, types.IsString),\n    ],\n    &quot;some metadata&quot;,\n  ),\n]\n```\n\nThis metadata can then be used to generate Gleam code that works with the `User`\nrecord (see [glerd_json](https://github.com/darky/glerd-json) for an example of\nreading this metadata and generating Gleam boilerplate code for\nencoding/decoding records to/from [JSON](https://www.json.org/json-en.html)).\n\n## Sample project\n\nIf you&#39;d like to try out Glerd, there is a\n[sample Gleam project](https://github.com/jasonprogrammer/glerd_example) with\ninstructions and a source file for quick testing.\n\n## Development\n\nRun:\n\n```sh\ngleam test # and then commit generated file\n```\n\n## See also\n\n* [Codegen for JSON encoders/decoders using Glerd](https://github.com/darky/glerd-json)\n* [Gleam Record validators using Glerd metadata](https://github.com/darky/glerd-valid)\n","url":"index.html"},{"doc":"glerd","title":"generate","content":"pub fn generate(root: String) -&gt; Nil\n\nSynonyms:\nglerd.generate\nglerd generate","url":"glerd.html#generate"},{"doc":"glerd","title":"main","content":"pub fn main() -&gt; Nil\n\nSynonyms:\nglerd.main\nglerd main","url":"glerd.html#main"},{"doc":"glerd","title":"glerd","content":"","url":"glerd.html"},{"doc":"glerd/types","title":"FieldType","content":"pub type FieldType {\n  IsString\n  IsInt\n  IsFloat\n  IsBool\n  IsNil\n  IsList(FieldType)\n  IsTuple2(FieldType, FieldType)\n  IsTuple3(FieldType, FieldType, FieldType)\n  IsTuple4(FieldType, FieldType, FieldType, FieldType)\n  IsTuple5(FieldType, FieldType, FieldType, FieldType, FieldType)\n  IsTuple6(\n    FieldType,\n    FieldType,\n    FieldType,\n    FieldType,\n    FieldType,\n    FieldType,\n  )\n  IsDict(FieldType, FieldType)\n  IsOption(FieldType)\n  IsResult(FieldType, FieldType)\n  IsRecord(String)\n  IsFunction0(FieldType)\n  IsFunction1(FieldType, FieldType)\n  IsFunction2(FieldType, FieldType, FieldType)\n  IsFunction3(FieldType, FieldType, FieldType, FieldType)\n  IsFunction4(\n    FieldType,\n    FieldType,\n    FieldType,\n    FieldType,\n    FieldType,\n  )\n  IsFunction5(\n    FieldType,\n    FieldType,\n    FieldType,\n    FieldType,\n    FieldType,\n    FieldType,\n  )\n  IsFunction6(\n    FieldType,\n    FieldType,\n    FieldType,\n    FieldType,\n    FieldType,\n    FieldType,\n    FieldType,\n  )\n}\n\nIsString\n\n\nIsInt\n\n\nIsFloat\n\n\nIsBool\n\n\nIsNil\n\n\nIsList(FieldType)\n\n\nIsTuple2(FieldType, FieldType)\n\n\nIsTuple3(FieldType, FieldType, FieldType)\n\n\nIsTuple4(FieldType, FieldType, FieldType, FieldType)\n\n\nIsTuple5(FieldType, FieldType, FieldType, FieldType, FieldType)\n\n\nIsTuple6(\n  FieldType,\n  FieldType,\n  FieldType,\n  FieldType,\n  FieldType,\n  FieldType,\n)\n\n\nIsDict(FieldType, FieldType)\n\n\nIsOption(FieldType)\n\n\nIsResult(FieldType, FieldType)\n\n\nIsRecord(String)\n\n\nIsFunction0(FieldType)\n\n\nIsFunction1(FieldType, FieldType)\n\n\nIsFunction2(FieldType, FieldType, FieldType)\n\n\nIsFunction3(FieldType, FieldType, FieldType, FieldType)\n\n\nIsFunction4(\n  FieldType,\n  FieldType,\n  FieldType,\n  FieldType,\n  FieldType,\n)\n\n\nIsFunction5(\n  FieldType,\n  FieldType,\n  FieldType,\n  FieldType,\n  FieldType,\n  FieldType,\n)\n\n\nIsFunction6(\n  FieldType,\n  FieldType,\n  FieldType,\n  FieldType,\n  FieldType,\n  FieldType,\n  FieldType,\n)\n\n\nSynonyms:\nglerd/types.FieldType\nglerd/types FieldType","url":"glerd/types.html#FieldType"},{"doc":"glerd/types","title":"glerd/types","content":"","url":"glerd/types.html"}]);